==> haskell-hls-floskell-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-floskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-floskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-floskell-plugin-2.1.0.0-1RXGCZaZ4a2Bmq0eB9ZnOI
key:                  hls-floskell-plugin-2.1.0.0-1RXGCZaZ4a2Bmq0eB9ZnOI
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Floskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  a3eab2740edf397c146019c1f8f27281
exposed:              True
exposed-modules:      Ide.Plugin.Floskell
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-floskell-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-floskell-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-floskell-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-floskell-plugin
hs-libraries:         HShls-floskell-plugin-2.1.0.0-1RXGCZaZ4a2Bmq0eB9ZnOI
depends:
    base-4.18.2.1 floskell-0.10.8-AxOvA0LXC8d9OWxkw4MIsF
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-floskell-plugin/html/hls-floskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-floskell-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-floskell-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-floskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-floskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-floskell-plugin-2.1.0.0-3tjWeyE8nxKDDdShaQKrxC
key:                  hls-floskell-plugin-2.1.0.0-3tjWeyE8nxKDDdShaQKrxC
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Floskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  04495aed29b7e5ad6539e01e086c3b18
exposed:              True
exposed-modules:      Ide.Plugin.Floskell
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-floskell-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-floskell-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-floskell-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-floskell-plugin
hs-libraries:         HShls-floskell-plugin-2.1.0.0-3tjWeyE8nxKDDdShaQKrxC
depends:
    base-4.18.2.1 floskell-0.10.8-A4Jk62LRm65KpwXvndUnOp
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lsp-types-2.0.1.0-16awFyiKGg1Iy6lHArG7S3 mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-floskell-plugin/html/hls-floskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-floskell-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
